@@ -15,25 +15,28 @@ def set_img_background():
 
     try:
         img = sys.argv[2]
-        if img == '-help':
+        if img == "-help":
             raise IndexError
         if not os.path.exists(img):
-            qs_default_console.log(qs_error_string, 'No Such File: %s' % img)
+            qs_default_console.log(qs_error_string, "No Such File: %s" % img)
             return
         to = sys.argv[3]
         try:
             frm = sys.argv[4]
         except IndexError:
-            frm = '0,0,0,0'
+            frm = "0,0,0,0"
     except IndexError:
-        qs_default_console.log(qs_error_string, 'Usage: qs stbg <picture> <to_color> [from_color: default transparency]')
+        qs_default_console.log(
+            qs_error_string,
+            "Usage: qs stbg <picture> <to_color> [from_color: default transparency]",
+        )
         return
     else:
         to = get_color_from_str(to)
         frm = get_color_from_str(frm)
         img = transport_back(img, to, frm)
-        iname = sys.argv[2].split('.')
-        iname = iname[0] + '_stbg.' + ''.join(iname[1:])
+        iname = sys.argv[2].split(".")
+        iname = iname[0] + "_stbg." + "".join(iname[1:])
         img.save(iname)
 
 
@@ -42,26 +45,28 @@ def fmt_img_color():
 
     try:
         img = sys.argv[2]
-        if img == '-help':
+        if img == "-help":
             raise IndexError
         if not os.path.exists(img):
-            qs_default_console.log(qs_error_string, 'No Such File: %s' % img)
+            qs_default_console.log(qs_error_string, "No Such File: %s" % img)
             return
         to = sys.argv[3]
         try:
             exp = sys.argv[4:]
         except IndexError:
-            exp = '0,0,0,0'
+            exp = "0,0,0,0"
     except IndexError:
-        qs_default_console.log(qs_error_string,
-                               'Usage: qs fmti <picture> <to_color> [except_color: default transparency]')
+        qs_default_console.log(
+            qs_error_string,
+            "Usage: qs fmti <picture> <to_color> [except_color: default transparency]",
+        )
         return
     else:
         to = get_color_from_str(to)
         exp = [get_color_from_str(i) for i in exp]
         img = formatOneColor(img, to, exp)
-        iname = sys.argv[2].split('.')
-        iname = iname[0] + '_fmt.' + ''.join(iname[1:])
+        iname = sys.argv[2].split(".")
+        iname = iname[0] + "_fmt." + "".join(iname[1:])
         img.save(iname)
 
 
@@ -75,28 +80,36 @@ def v2gif():
         if len(sys.argv) > 3:
             for i in sys.argv[3:]:
                 try:
-                    if ',' in i:
-                        sz = tuple([int(j) for j in i.split(',')])
+                    if "," in i:
+                        sz = tuple([int(j) for j in i.split(",")])
                     else:
                         fps = int(i)
                 except:
                     raise IndexError
-        sz = tuple([int(i) for i in sys.argv[3].split(',')]) if len(sys.argv) > 3 and ',' in sys.argv[3] else None
+        sz = (
+            tuple([int(i) for i in sys.argv[3].split(",")])
+            if len(sys.argv) > 3 and "," in sys.argv[3]
+            else None
+        )
     except IndexError:
-        qs_default_console.log(qs_error_string, 'Usage: qs v2gif <*.mp4> [width,height] [fps]')
+        qs_default_console.log(
+            qs_error_string, "Usage: qs v2gif <*.mp4> [width,height] [fps]"
+        )
         return
     else:
-        video_2_gif(video, sz, fps) if sz and fps else video_2_gif(video, sz) \
-            if sz else video_2_gif(video, fps=fps) if fps else video_2_gif(video)
+        video_2_gif(video, sz, fps) if sz and fps else video_2_gif(
+            video, sz
+        ) if sz else video_2_gif(video, fps=fps) if fps else video_2_gif(video)
 
 
 def remove_audio():
     """删除视频的音频 | remove audio in mp4"""
     from .ImageTools.VideoTools import rm_audio
+
     try:
         videos = sys.argv[2:]
     except IndexError:
-        qs_default_console.log(qs_error_string, 'Usage: qs rmaudio <video...>')
+        qs_default_console.log(qs_error_string, "Usage: qs rmaudio <video...>")
     else:
         for video in videos:
             rm_audio(video)
@@ -105,10 +118,11 @@ def remove_audio():
 def v2mp4():
     """视频转mp4 | transfer video to mp4"""
     from .ImageTools.VideoTools import tomp4
+
     try:
         videos = sys.argv[2:]
     except IndexError:
-        qs_default_console.log(qs_error_string, 'Usage: qs v2mp4 <video...>')
+        qs_default_console.log(qs_error_string, "Usage: qs v2mp4 <video...>")
     else:
         for video in videos:
             tomp4(video)
@@ -117,10 +131,11 @@ def v2mp4():
 def v2mp3():
     """提取视频音频为mp3 | Extract the audio from the video and save it in MP3 format"""
     from .ImageTools.VideoTools import video_2_mp3
+
     try:
         videos = sys.argv[2:]
     except IndexError:
-        qs_default_console.log(qs_error_string, 'Usage: qs v2mp3 <video...>')
+        qs_default_console.log(qs_error_string, "Usage: qs v2mp3 <video...>")
     else:
         for video in videos:
             video_2_mp3(video)
@@ -130,30 +145,40 @@ def icat():
     """Mac::iTerm下预览图片 | Preview the picture under Mac::iTerm"""
     try:
         path = sys.argv[2]
-        is_url = '-open_url' in sys.argv or \
-                 (not os.path.exists(path) and (path.startswith('http://') or path.startswith('https://')))
-        is_in_rc_file = '--rc' in sys.argv
+        is_url = "-open_url" in sys.argv or (
+            not os.path.exists(path)
+            and (path.startswith("http://") or path.startswith("https://"))
+        )
+        is_in_rc_file = "--rc" in sys.argv
         if is_in_rc_file:
-            rc_width = int(sys.argv[sys.argv.index('--rc') + 1])
+            rc_width = int(sys.argv[sys.argv.index("--rc") + 1])
         else:
             rc_width = 0
         if not os.path.exists(path) and not is_url:
-            qs_default_console.log(qs_error_string, 'No such file:', path)
+            qs_default_console.log(qs_error_string, "No such file:", path)
             raise FileNotFoundError
     except:
-        qs_default_console.log(qs_error_string, 'Usage: qs icat <img path/url> [-open_url if is url]')
+        qs_default_console.log(
+            qs_error_string, "Usage: qs icat <img path/url> [-open_url if is url]"
+        )
     else:
         from .ImageTools.ImagePreview import image_preview
-        image_preview(open(path), set_width_in_rc_file=rc_width, force_show=True) if not is_url else image_preview(path, is_url, set_width_in_rc_file=rc_width, force_show=True)
+
+        image_preview(
+            open(path), set_width_in_rc_file=rc_width, force_show=True
+        ) if not is_url else image_preview(
+            path, is_url, set_width_in_rc_file=rc_width, force_show=True
+        )
 
 
 def i2png():
     try:
         imgs = sys.argv[2:]
     except IndexError:
-        qs_default_console.log(qs_error_string, 'Usage: qs i2png <imgs...>')
+        qs_default_console.log(qs_error_string, "Usage: qs i2png <imgs...>")
     else:
         from .ImageTools.ImageTools import topng
+
         for imgPath in imgs:
             topng(imgPath)
 
@@ -162,16 +187,20 @@ def i2jpg():
     try:
         imgs = sys.argv[2:]
     except IndexError:
-        qs_default_console.log(qs_error_string, 'Usage: qs i2jpg <imgs...>')
+        qs_default_console.log(qs_error_string, "Usage: qs i2jpg <imgs...>")
     else:
         from .ImageTools.ImageTools import tojpg
+
         for imgPath in imgs:
             tojpg(imgPath)
 
 
 def vsta():
     from .ImageTools.VideoTools import set_video_audio
+
     try:
         set_video_audio(*sys.argv[2:])
     except Exception as e:
-        qs_default_console.log(qs_error_string, f'{repr(e)}\nUsage: qs vsta <video> <audio>')
+        qs_default_console.log(
+            qs_error_string, f"{repr(e)}\nUsage: qs vsta <video> <audio>"
+        )
